--- FTPConnectionClosedException.java	Thu Aug  6 19:25:53 2009
+++ SMTPConnectionClosedException.java	Thu Aug  6 19:25:25 2009
@@ -1,91 +1,52 @@
-package org.apache.commons.net.ftp;
-
-/* ====================================================================
- * The Apache Software License, Version 1.1
+/*
+ * Copyright 2001-2004 The Apache Software Foundation
  *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Apache" and "Apache Software Foundation" and
- *    "Apache Commons" must not be used to endorse or promote products
- *    derived from this software without prior written permission. For
- *    written permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without
- *    prior written permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
+package org.apache.commons.net.smtp;
 
 import java.io.IOException;
 
 /***
  * FTPConnectionClosedException is used to indicate the premature or
  * unexpected closing of an FTP connection resulting from a 
  * <a href="org.apache.commons.net.ftp.FTPReply.html#SERVICE_NOT_AVAILABLE">
  * FTPReply.SERVICE_NOT_AVAILABLE </a> response (FTP reply code 421) to a
  * failed FTP command.  This exception is derived from IOException and
  * therefore may be caught either as an IOException or specifically as an
- * FTPConnectionClosedException.
+ * SMTPConnectionClosedException.
  * <p>
  * <p>
  * @author Daniel F. Savarese
- * @see FTP
- * @see FTPClient
+ * @see SMTP
+ * @see SMTPClient
  ***/
 
-public class FTPConnectionClosedException extends IOException
+public final class SMTPConnectionClosedException extends IOException
 {
 
-    /*** Constructs a FTPConnectionClosedException with no message ***/
-    public FTPConnectionClosedException()
+    /*** Constructs a SMTPConnectionClosedException with no message ***/
+    public SMTPConnectionClosedException()
     {
         super();
     }
 
     /***
      * Constructs a FTPConnectionClosedException with a specified message.
      * <p>
      * @param message  The message explaining the reason for the exception.
      ***/
-    public FTPConnectionClosedException(String message)
+    public SMTPConnectionClosedException(String message)
     {
         super(message);
     }
@@ -1,91 +1,52 @@
 
 /***
- * FTPConnectionClosedException is used to indicate the premature or
- * unexpected closing of an FTP connection resulting from a 
- * <a href="org.apache.commons.net.ftp.FTPReply.html#SERVICE_NOT_AVAILABLE">
- * FTPReply.SERVICE_NOT_AVAILABLE </a> response (FTP reply code 421) to a
- * failed FTP command.  This exception is derived from IOException and
+ * SMTPConnectionClosedException is used to indicate the premature or
+ * unexpected closing of an SMTP connection resulting from a
+ * <a href="org.apache.commons.net.smtp.SMTPReply.html#SERVICE_NOT_AVAILABLE">
+ * SMTPReply.SERVICE_NOT_AVAILABLE </a> response (SMTP reply code 421) to a
+ * failed SMTP command.  This exception is derived from IOException and
  * therefore may be caught either as an IOException or specifically as an
@@ -1,91 +1,52 @@
 
     /***
-     * Constructs a FTPConnectionClosedException with a specified message.
+     * Constructs a SMTPConnectionClosedException with a specified message.
      * <p>
      * @param message  The message explaining the reason for the exception.
